package validatorissue;

import java.util.Set;
import javax.validation.ConstraintViolation;
import javax.validation.Validation;
import javax.validation.Validator;
import javax.validation.ValidatorFactory;
import org.junit.BeforeClass;
import org.junit.Test;
import static org.junit.Assert.*;

/**
 * @author Xavier Sosnovsky <xso@sosna.ws>
 */
public class ExampleTest {
    
    private static Validator validator;
    
    @BeforeClass
    public static void setUpClass() {
        ValidatorFactory factory = Validation.buildDefaultValidatorFactory();
        validator = factory.getValidator();
    }
    
    // Test OK. Validation reports no error, as expected.
    @Test
    public void validationOk() {
        final Example instance = new Example(47.5913904235);
        Set<ConstraintViolation<Example>> constraintViolations
            = validator.validate(instance);
        assertEquals(0, constraintViolations.size());
    }
    
    // Test OK. Validation reports an error, as expected.
    @Test
    public void wrongLatitude() {
        final Example instance = new Example(97.5913904235);
        Set<ConstraintViolation<Example>> constraintViolations
            = validator.validate(instance);
        assertEquals(1, constraintViolations.size());
    }
    
    // Test NOK. An exception is thrown.
    @Test
    public void infiniteLatitude() {
        final Example instance = new Example(Double.POSITIVE_INFINITY);
        Set<ConstraintViolation<Example>> constraintViolations
            = validator.validate(instance);
        assertEquals(1, constraintViolations.size());
    }
}
